@@ -2,6 +2,7 @@ var group__cyclic__refresh =
 [
     [ "CYCLIC_REFRESH", "structCYCLIC__REFRESH.html", [
       [ "percent_refresh", "structCYCLIC__REFRESH.html#ae315bcaf369b95ab1162f2d1271263de", null ],
+      [ "percent_refresh_adjustment", "structCYCLIC__REFRESH.html#ad8b57361f650ec0720a5fff2367602e4", null ],
       [ "max_qdelta_perc", "structCYCLIC__REFRESH.html#a441d4805353c603874ae7f356a649cd3", null ],
       [ "sb_index", "structCYCLIC__REFRESH.html#ad45cfe66fc5d1ab8aecee9bc1ef72f44", null ],
       [ "time_for_refresh", "structCYCLIC__REFRESH.html#a14a2e1c9b9ca6a36bb29ccd9a0e02002", null ],
@@ -14,11 +15,12 @@ var group__cyclic__refresh =
       [ "thresh_dist_sb", "structCYCLIC__REFRESH.html#a74276b39125b068743f0b6dc2ba0f36a", null ],
       [ "motion_thresh", "structCYCLIC__REFRESH.html#a08162f2bd6028160d470024577dfcec6", null ],
       [ "rate_ratio_qdelta", "structCYCLIC__REFRESH.html#afe7bf45e2c31665d7d64254c23fdaf6c", null ],
+      [ "rate_ratio_qdelta_adjustment", "structCYCLIC__REFRESH.html#aab71afb9e2f97492ee5b8072ebffc743", null ],
       [ "rate_boost_fac", "structCYCLIC__REFRESH.html#ae0966dda4b2470d422129ed473e39d4c", null ]
     ] ],
     [ "av1_cyclic_refresh_estimate_bits_at_q", "group__cyclic__refresh.html#ga3703e9a518f8f17e7b6b601a456dbde8", null ],
     [ "av1_cyclic_refresh_rc_bits_per_mb", "group__cyclic__refresh.html#ga1e8e194fae8285692651fb856b49c185", null ],
-    [ "av1_cyclic_reset_segment_skip", "group__cyclic__refresh.html#gafb17f1befe613fac6ceebb9b5b24ebd8", null ],
+    [ "av1_cyclic_reset_segment_skip", "group__cyclic__refresh.html#ga6a9f795a98618a842fece25ef85f20cf", null ],
     [ "av1_cyclic_refresh_update_segment", "group__cyclic__refresh.html#ga35ec71ccbbc64bcb31ed02229dfe9ae0", null ],
     [ "av1_init_cyclic_refresh_counters", "group__cyclic__refresh.html#gab63536700b85e6560aed37f0b8afbcaf", null ],
     [ "av1_accumulate_cyclic_refresh_counters", "group__cyclic__refresh.html#gaa4acc60c7ec3fc459b5ce65920493823", null ],
