@@ -5,11 +5,6 @@ var NAVTREEINDEX0 =
 "LREADME.html#additional-test-data":[10,0,2,4],
 "LREADME.html#autotoc_md0":[10,0],
 "LREADME.html#autotoc_md1":[10,0,0],
-"LREADME.html#autotoc_md2":[10,0,2,0,0],
-"LREADME.html#autotoc_md3":[10,0,2,0,1],
-"LREADME.html#autotoc_md4":[10,0,2,0,2],
-"LREADME.html#autotoc_md5":[10,0,2,5,0],
-"LREADME.html#autotoc_md6":[10,0,2,5,1],
 "LREADME.html#basic-build":[10,0,1,2],
 "LREADME.html#bug-reports":[10,0,6],
 "LREADME.html#build-with-vmaf":[10,0,1,12],
@@ -23,6 +18,8 @@ var NAVTREEINDEX0 =
 "LREADME.html#downloading-the-test-data":[10,0,2,2],
 "LREADME.html#dylib-builds":[10,0,1,4],
 "LREADME.html#emscripten-builds":[10,0,1,10],
+"LREADME.html#encoder-tests":[10,0,2,0,2],
+"LREADME.html#example-tests":[10,0,2,0,1],
 "LREADME.html#extra-build-flags":[10,0,1,11],
 "LREADME.html#get-the-code":[10,0,1,1],
 "LREADME.html#ide-hosted-tests":[10,0,2,1],
@@ -30,6 +27,8 @@ var NAVTREEINDEX0 =
 "LREADME.html#login-cookie":[10,0,4,0],
 "LREADME.html#microsoft-visual-studio-builds":[10,0,1,8],
 "LREADME.html#prerequisites":[10,0,1,0],
+"LREADME.html#running-test_libaom-directly":[10,0,2,5,0],
+"LREADME.html#running-the-tests-via-the-cmake-build":[10,0,2,5,1],
 "LREADME.html#sanitizers":[10,0,1,7],
 "LREADME.html#sharded-testing":[10,0,2,5],
 "LREADME.html#submitting-patches":[10,0,4],
@@ -38,22 +37,16 @@ var NAVTREEINDEX0 =
 "LREADME.html#testing-basics":[10,0,2,0],
 "LREADME.html#testing-the-av1-codec":[10,0,2],
 "LREADME.html#testing-your-code":[10,0,4,2],
+"LREADME.html#unit-tests":[10,0,2,0,0],
 "LREADME.html#upload-your-change":[10,0,4,4],
 "LREADME.html#viewing-the-status-of-uploaded-changes":[10,0,4,7],
 "LREADME.html#xcode-builds":[10,0,1,9],
 "annotated.html":[13,0],
-"aom_8h.html":[14,0,0,0],
-"aom_8h_source.html":[14,0,0,0],
-"aom__codec_8h.html":[14,0,0,1],
-"aom__codec_8h_source.html":[14,0,0,1],
-"aom__decoder_8h.html":[14,0,0,2],
-"aom__decoder_8h_source.html":[14,0,0,2],
-"aom__encoder_8h.html":[14,0,0,3],
-"aom__encoder_8h.html#a3ec4904ea175471a03d10705f384d07c":[14,0,0,3,7],
-"aom__encoder_8h.html#a446aae868ff07f3971d9e84b6602a890":[14,0,0,3,8],
-"aom__encoder_8h_source.html":[14,0,0,3],
-"aom__external__partition_8h.html":[14,0,0,4],
-"aom__external__partition_8h_source.html":[14,0,0,4],
+"aom_8h.html":[12,1,0,2],
+"aom__codec_8h.html":[12,0,2],
+"aom__decoder_8h.html":[12,0,0,1],
+"aom__encoder_8h.html":[12,0,1,0],
+"aom__external__partition_8h.html":[12,1,0,0,0],
 "aom__frame__buffer_8h.html":[14,0,0,5],
 "aom__frame__buffer_8h.html#a01fdfbbc9be8b320437a49d3de07814d":[14,0,0,5,4],
 "aom__frame__buffer_8h.html#a1803cd0766dc297d88172f174fbb6ab5":[14,0,0,5,5],
@@ -177,10 +170,8 @@ var NAVTREEINDEX0 =
 "aom__image_8h.html#afff22f7f3eb9409c5b678d1962f110a8":[14,0,0,6,33],
 "aom__image_8h_source.html":[14,0,0,6],
 "aom__integer_8h_source.html":[14,0,0,7],
-"aomcx_8h.html":[14,0,0,8],
-"aomcx_8h_source.html":[14,0,0,8],
-"aomdx_8h.html":[14,0,0,9],
-"aomdx_8h_source.html":[14,0,0,9],
+"aomcx_8h.html":[12,1,0,0,1],
+"aomdx_8h.html":[12,1,0,1,0],
 "aq__cyclicrefresh_8h_source.html":[14,0,2,2,0],
 "av1__common__int_8h_source.html":[14,0,2,0,0],
 "av1__loopfilter_8h_source.html":[14,0,2,0,1],
@@ -200,15 +191,43 @@ var NAVTREEINDEX0 =
 "decoder_8h_source.html":[14,0,2,1,0],
 "decoder_guide.html":[7],
 "deprecated.html":[11],
-"dir_83b20852c9912465ee56087df726e108.html":[14,0,1],
-"dir_a274709e123b533dad4a228d330a7150.html":[14,0,2,2],
-"dir_b4e03821b9334beff9137621096f6edd.html":[14,0,2],
-"dir_cb27e53820231bed3b68debf117d91db.html":[14,0,2,0],
-"dir_f0b4f90b21a4663c5706dd5b29fcc072.html":[14,0,2,1],
-"dir_f7205fd35d1d71ebd34002f1c2b4a130.html":[14,0,0],
+"dir_1643cd6aef5124e2f1d93316fd3b6d68.html":[14,0,2,1],
+"dir_577694aa439cb3386b056254ab843995.html":[14,0,2],
+"dir_7cc58bcc994aa3ebc7c176bc2b655f3c.html":[14,0,0],
+"dir_9d5cb09d52f4ffc29a55beecca0c755f.html":[14,0,1],
+"dir_e26add0cb01f0446a3910f0c4d4c987e.html":[14,0,2,0],
+"dir_f0fbb790e1ebe4029c655fa771f566e3.html":[14,0,2,2],
 "encode__strategy_8h.html":[14,0,2,2,3],
 "encode__strategy_8h_source.html":[14,0,2,2,3],
 "encoder_8h.html":[14,0,2,2,4],
+"encoder_8h.html#a0207efa57c443f3ff9e157c22c532b5f":[14,0,2,2,4,47],
+"encoder_8h.html#a03bce75164cb579c775759205ed26055":[14,0,2,2,4,50],
+"encoder_8h.html#a03bce75164cb579c775759205ed26055a0387b2a2bbc01b142f3716c18a97fe9d":[14,0,2,2,4,50,1],
+"encoder_8h.html#a03bce75164cb579c775759205ed26055a6e437058362eef3c17fc5c856202dee3":[14,0,2,2,4,50,2],
+"encoder_8h.html#a03bce75164cb579c775759205ed26055a6f0f4239b7fc9f98980631093f885cc0":[14,0,2,2,4,50,3],
+"encoder_8h.html#a03bce75164cb579c775759205ed26055a7155daf31c8b01be1e8093e8e36ce6fb":[14,0,2,2,4,50,4],
+"encoder_8h.html#a03bce75164cb579c775759205ed26055a7ab17ad52ce554037df368d89cef2c02":[14,0,2,2,4,50,0],
+"encoder_8h.html#a1abd57b3c653bb72dee5f88ba45f1cda":[14,0,2,2,4,49],
+"encoder_8h.html#a1e0a95f3ba85551b4280ef86a45235bb":[14,0,2,2,4,43],
+"encoder_8h.html#a246db68993252fe81c1e5a911575efb4":[14,0,2,2,4,48],
+"encoder_8h.html#a371e7dff2f6e26ebcb3ac61fd872a21f":[14,0,2,2,4,44],
+"encoder_8h.html#a4a823cfecd8aa8c27bd6670df6ad9713":[14,0,2,2,4,45],
+"encoder_8h.html#a763875a39b7bd1931c473816cce5b526":[14,0,2,2,4,51],
+"encoder_8h.html#a763875a39b7bd1931c473816cce5b526a0ef541f183d3eca96af1646512a5b8a2":[14,0,2,2,4,51,1],
+"encoder_8h.html#a763875a39b7bd1931c473816cce5b526a2e00e0285db43d464e21e0669918cdc3":[14,0,2,2,4,51,3],
+"encoder_8h.html#a763875a39b7bd1931c473816cce5b526ab09c9bc921ce3db1d2de31f412320b2e":[14,0,2,2,4,51,2],
+"encoder_8h.html#a763875a39b7bd1931c473816cce5b526abcdd38fc3c9d28ee7bc6f239d6398c80":[14,0,2,2,4,51,0],
+"encoder_8h.html#a7c7530c349e3a9478e879f6d16884282":[14,0,2,2,4,38],
+"encoder_8h.html#a9af93120431b9d96ca04670151ea562c":[14,0,2,2,4,46],
+"encoder_8h.html#a9f8c3abfb05222c315bd3051a142c718":[14,0,2,2,4,41],
+"encoder_8h.html#abcba64e654f5bcb3ba1449668c424906":[14,0,2,2,4,52],
+"encoder_8h.html#abcba64e654f5bcb3ba1449668c424906a25996ba4d7d8bc9836af3a40689741f3":[14,0,2,2,4,52,2],
+"encoder_8h.html#abcba64e654f5bcb3ba1449668c424906a41aadbdfa9e5c7d0b653e2f26753ed06":[14,0,2,2,4,52,0],
+"encoder_8h.html#abcba64e654f5bcb3ba1449668c424906aae78505d57c712c615f99f18f7fefad0":[14,0,2,2,4,52,1],
+"encoder_8h.html#abcba64e654f5bcb3ba1449668c424906af1fefe2fd9bbb67acadecac23e931f61":[14,0,2,2,4,52,3],
+"encoder_8h.html#add3c378ea62064e99094302a4af0fe64":[14,0,2,2,4,42],
+"encoder_8h.html#ae37f210917b9733abc7ca81445427d71":[14,0,2,2,4,40],
+"encoder_8h.html#af2bb9f0bb51c031007f05054a3bf6b07":[14,0,2,2,4,39],
 "encoder_8h_source.html":[14,0,2,2,4],
 "encoder_guide.html":[8],
 "encoder_guide.html#architecture_av1_structure":[8,0,1],
@@ -230,24 +249,5 @@ var NAVTREEINDEX0 =
 "encoder_guide.html#architecture_enc_frame_proc_tf_overview":[8,5,2,0],
 "encoder_guide.html#architecture_enc_gf_length":[8,7,2],
 "encoder_guide.html#architecture_enc_gf_structure":[8,7,3],
-"encoder_guide.html#architecture_enc_inter_modes":[8,11],
-"encoder_guide.html#architecture_enc_intra_modes":[8,10],
-"encoder_guide.html#architecture_enc_kf_groups":[8,7,4],
-"encoder_guide.html#architecture_enc_partitions":[8,9],
-"encoder_guide.html#architecture_enc_rate_ctrl":[8,6],
-"encoder_guide.html#architecture_enc_rate_ctrl_data":[8,6,0],
-"encoder_guide.html#architecture_enc_rate_ctrl_options":[8,6,1],
-"encoder_guide.html#architecture_enc_rc_loop":[8,6,3],
-"encoder_guide.html#architecture_enc_speed_quality":[8,4],
-"encoder_guide.html#architecture_enc_src_proc":[8,5],
-"encoder_guide.html#architecture_enc_tpl":[8,8],
-"encoder_guide.html#architecture_enc_tpl_algoritms":[8,8,1],
-"encoder_guide.html#architecture_enc_tpl_config":[8,8,0],
-"encoder_guide.html#architecture_enc_tpl_keyfun":[8,8,2],
-"encoder_guide.html#architecture_enc_tx_search":[8,12],
-"encoder_guide.html#architecture_enc_use_cases":[8,3],
-"encoder_guide.html#architecture_enc_vbr":[8,6,2],
-"encoder_guide.html#architecture_entropy":[8,14],
-"encoder_guide.html#architecture_entropy_aritmetic":[8,14,0],
-"encoder_guide.html#architecture_entropy_coef":[8,14,1]
+"encoder_guide.html#architecture_enc_inter_modes":[8,11]
 };
