@@ -8,5 +8,6 @@ var structHIGH__LEVEL__SPEED__FEATURES =
     [ "superres_auto_search_type", "structHIGH__LEVEL__SPEED__FEATURES.html#ab0d822dd440fca06dadbd042fa749881", null ],
     [ "disable_extra_sc_testing", "structHIGH__LEVEL__SPEED__FEATURES.html#a93f9d17662d20445b49262ef01880a6b", null ],
     [ "second_alt_ref_filtering", "structHIGH__LEVEL__SPEED__FEATURES.html#a1f5862490fb7b03317b66f8578271a30", null ],
-    [ "num_frames_used_in_tf", "structHIGH__LEVEL__SPEED__FEATURES.html#ae274fdbc21d1f9709514e2c6a77eab5b", null ]
+    [ "num_frames_used_in_tf", "structHIGH__LEVEL__SPEED__FEATURES.html#ae274fdbc21d1f9709514e2c6a77eab5b", null ],
+    [ "accurate_bit_estimate", "structHIGH__LEVEL__SPEED__FEATURES.html#ad4e0881065dd85ccb05b27099c3d8386", null ]
 ];
\ No newline at end of file
